bayespy.inference.vmp.nodes.binomial.BinomialDistribution.compute_mask_to_parent
================================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.binomial

.. automethod:: BinomialDistribution.compute_mask_to_parent